// Reading the CSV file from gist
d3.csv(
  'https://gist.githubusercontent.com/PavanKrishnaYarlagadda/2ec95c7b05226d6fdbbfd322ed8458f3/raw/3a51cbb9cf614868c029edf74d90ccb9f786562d/weather.csv',
)
  .then(function (data) {
    
    // Convert string data to numerical values
    data.forEach(function (d) {
      d.Temperature = +d.Temperature;
      d.Humidity = +d.Humidity;
    });

    // Call function to draw scatter plot
    drawScatterPlot(data);
  })
  .catch(function (error) {
    // Handle errors while loading data
    console.log('Error loading the data');
    throw error;
  });

// Function to draw the scatter plot
function drawScatterPlot(data) {
  // Margins and dimensions for the plot
  const margin = {
    top: 20,
    right: 20,
    bottom: 50,
    left: 50,
  };
  const width = 600 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  // Select the scatter plot container and append an SVG element
  const svg = d3
    .select('#scatter-plot')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Create scales for x and y axes
  const x = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Temperature)])
    .range([0, width]);

  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Humidity)])
    .range([height, 0]);

  // Append x and y axes to the SVG element
  svg
    .append('g')
    .attr('transform', `translate(0,${height})`)
    .call(d3.axisBottom(x))
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.bottom - 5)
    .attr('fill', '#000')
    .style('text-anchor', 'middle')
    .text('Temperature');

  svg
    .append('g')
    .call(d3.axisLeft(y))
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', -margin.left + 10)
    .attr('x', -height / 2)
    .attr('fill', '#000')
    .style('text-anchor', 'middle')
    .text('Humidity');

  // Append circles for data points
  svg
    .selectAll('circle')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'circle')
    .attr('cx', (d) => x(d.Temperature))
    .attr('cy', (d) => y(d.Humidity))
    .attr('r', 5);
}
